Module

Struct Module 

pub struct Module {
    pub name: String,
    pub root: PathBuf,
    pub config: Option<Sourced<Config>>,
    pub src_path: PathBuf,
}
Either the main project or a plugin

Fields

name: Stringroot: PathBufconfig: Option<Sourced<Config>>src_path: PathBuf

Implementations

Source

impl Module

pub fn load<S: Into<String>>(name: S, root: &Path) -> DdResult<Self>

Load the module from the given root directory, reading its config file (which is optional when the module is a plugin (i.e. name is not empty), but required when it’s the main project).

pub fn is_main(&self) -> bool

pub fn list_js(&self, entries: &mut Vec<StaticEntry>) -> DdResult<()>

pub fn list_css(&self, entries: &mut Vec<StaticEntry>) -> DdResult<()>

pub fn add_watch_targets(&self, targets: &mut Vec<WatchTarget>)

pub fn copy_all_statics_into(&self, build_root: &Path) -> DdResult<()>